@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2021-11-26 14:01:50
+@LastEditTime: 2021-12-07 19:02:19
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -102,10 +102,15 @@ class CmsInfoListHandler(ClientBaseHandler):
         page_size = int(self.get_param("page_size", 20))
         page_index = int(self.get_param("page_index", 0))
 
+        order_by = "id desc"
+        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
+        else:
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
-        page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, app_id=app_id, act_id=act_id, is_cache=True), ref_params={})
+        page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True), ref_params={})
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
         return self.response_json_success(page_info)
