@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 09:24:50
-@LastEditTime: 2021-10-11 18:07:00
+@LastEditTime: 2021-12-20 17:37:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,7 +16,6 @@ class SkuInfoHandler(ClientBaseHandler):
     """
     :description: 获取SKU信息
     """
-    @filter_check_params("num_iid")
     def get_async(self):
         """
         :description: 获取SKU信息
@@ -25,9 +24,12 @@ class SkuInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        num_iid = self.get_param("num_iid")
         is_log = bool(self.get_param("is_log", False))
-
+        num_iid = self.get_param("num_iid")
+        if not num_iid:
+            num_iid = self.get_param("num_iids")
+        if not num_iid: 
+            return self.response_json_error("param_error", "参数错误,缺少必传参数")
         top_base_model = TopBaseModel(context=self)
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
