@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-12-08 16:27:23
+@LastEditTime: 2021-12-15 13:41:49
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -543,3 +543,42 @@ class BrowseSiteHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
+
+
+class ShareHandler(ClientBaseHandler):
+    """
+    :description: 分享奖励任务
+    """
+    @filter_check_params("act_id,tb_user_id,login_token")
+    def get_async(self):
+        """
+        :description: 分享奖励任务
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param tb_user_id:用户标识
+        :param login_token:访问令牌
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_source_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        user_id = self.get_user_id()
+        module_id = int(self.get_param("module_id", 0))
+        login_token = self.get_param("login_token")
+        task_base_model = TaskBaseModel(context=self)
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
+        check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
+        continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        invoke_result_data = task_base_model.process_share(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        return self.response_json_success(invoke_result_data.data)
