@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:15:49
-@LastEditTime: 2021-10-10 15:42:27
+@LastEditTime: 2021-11-25 10:41:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -60,9 +60,10 @@ class SaveThemeHandler(ClientBaseHandler):
         server_json = self.get_param("server_json")
         out_id = self.get_param("out_id")
         ver_no = self.get_param("ver_no")
+        style_type = int(self.get_param("style_type",0))
 
         theme_base_model = ThemeBaseModel(context=self)
-        theme_base_model.save_theme(app_id, theme_name, client_json, server_json, out_id, ver_no)
+        theme_base_model.save_theme(app_id, theme_name, client_json, server_json, out_id, ver_no, style_type)
         return self.response_json_success()
 
 
