@@ -2,10 +2,14 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 14:09:43
-@LastEditTime: 2021-07-19 13:58:42
+@LastEditTime: 2021-08-10 16:42:18
 @LastEditors: HuangJianYi
 :description: 通用Handler
 """
+from seven_framework.config import *
+from seven_framework.redis import *
+from seven_framework.web_tornado.base_handler.base_api_handler import *
+
 from seven_cloudapp_frame.handlers.frame_base import *
 
 
@@ -18,6 +22,6 @@ class IndexHandler(FrameBaseHandler):
         :description: 默认页
         :param 
         :return 字符串
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         self.write(UUIDHelper.get_uuid() + "_" + config.get_value("run_port") + "_api")
\ No newline at end of file
