@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-11-29 16:38:29
+@LastEditTime: 2021-12-20 15:59:20
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -20,9 +20,12 @@ class ActTypeListHandler(ClientBaseHandler):
         """
         :description: 获取活动类型列表
         :param marketing_id：营销方案标识
+        :param is_act：当前类型是否创建过活动
         :return: 
         :last_editors: HuangJianYi
         """
+        app_id = self.get_app_id()
+        is_act = int(self.get_param("is_act", 0))
         marketing_id = int(self.get_param("marketing_id", 0))
         condition = "market_ids LIKE '%," + str(marketing_id) + ",%'" if marketing_id > 0 else ""
         act_type_list = ActTypeModel(context=self).get_cache_list(where=condition)
@@ -33,6 +36,12 @@ class ActTypeListHandler(ClientBaseHandler):
             act_type.market_function_json = self.json_loads(act_type.market_function_json) if act_type.market_function_json else {}
             act_type.type_desc = self.json_loads(act_type.type_desc) if act_type.type_desc else []
             act_type.task_asset_type_json = self.json_loads(act_type.task_asset_type_json) if act_type.task_asset_type_json else []
+            if is_act > 0 and app_id:
+                act_dict = ActInfoModel(context=self).get_cache_dict("app_id=%s and act_type=%s", field="id", params=[app_id, act_type.id])
+                if act_dict:
+                    act_type.act_id = act_dict['id']
+                else:
+                    act_type.act_id = 0
             new_list.append(act_type.__dict__)
         return self.response_json_success(new_list)
 
