@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-11-29 19:25:18
+@LastEditTime: 2021-12-01 18:11:13
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -66,7 +66,6 @@ class PrizeOrderListHandler(ClientBaseHandler):
         :param order_status：订单状态（-1未付款-2付款中0未发货1已发货2不予发货3已退款4交易成功）
         :param create_date_start：订单创建时间开始
         :param create_date_end：订单创建时间结束
-        :param order_by：排序
         :param is_search_roster：是否查询订单关联中奖记录
         :param page_size：页大小
         :param page_index：页索引
@@ -100,9 +99,9 @@ class PrizeOrderListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
 
         order_base_model = OrderBaseModel(context=self)
-        page_list, total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False)
+        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False)
         ref_params = {}
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
+        page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
 
 
@@ -140,7 +139,6 @@ class PrizeRosterListHandler(ClientBaseHandler):
         user_open_id = self.get_param("user_open_id")
         order_no = self.get_param("order_no")
         user_nick = self.get_param("nick_name")
-        is_order = self.get_param("is_order",False)
         goods_type = int(self.get_param("goods_type", -1))
         prize_type = int(self.get_param("prize_type", -1))
         logistics_status = int(self.get_param("logistics_status", -1))
@@ -150,8 +148,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         create_date_end = self.get_param("create_date_end")
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
-        if is_order:
-            prize_status = 1
+
         condition = ""
         params = []
         order_by ="create_date desc"
@@ -163,8 +160,10 @@ class PrizeRosterListHandler(ClientBaseHandler):
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params,is_cache=False))
-
+        page_info = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params,is_cache=False)
+        ref_params = {}
+        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        return self.response_json_success(page_info)
 
 
 class UpdatePrizeOrderSellerRemarkHandler(ClientBaseHandler):
@@ -284,10 +283,11 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         telephone = self.get_param("telephone")
         address = self.get_param("address")
         real_name = self.get_param("real_name")
-        order_status = int(self.get_param("order_status", -1))
+        order_status = int(self.get_param("order_status", -10))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
-        order_by = self.get_param("order_by", "create_date desc")
+
+        order_by = "create_date desc"
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
@@ -375,7 +375,6 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         user_id = self.get_user_id()
         user_nick = self.get_param("nick_name")
         user_open_id = self.get_param("user_open_id")
-        is_order = self.get_param("is_order")
         goods_type = int(self.get_param("goods_type", -1))
         prize_type = int(self.get_param("prize_type", -1))
         logistics_status = int(self.get_param("logistics_status", -1))
@@ -383,8 +382,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         pay_status = int(self.get_param("pay_status", -1))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
-        if is_order:
-            prize_status = 1
+
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end).data
         ref_params = {}
