@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-12-06 17:43:49
+@LastEditTime: 2021-12-16 11:27:09
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -271,7 +271,7 @@ class SevenHelper:
     @classmethod
     def get_random(self,length):
         """
-        :description: 获取随机数
+        :description: 获取随机字符串
         :param length：长度
         :return: str
         :last_editors: HuangJianYi
