@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-12-06 17:11:29
+@LastEditTime: 2021-12-16 10:00:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -19,13 +19,14 @@ class StatConsoleModel():
     """
     :description: 统计控制台业务模型
     """
-    def console_stat_queue(self):
+    def console_stat_queue(self, mod_count=1):
         """
         :description: 控制台统计上报
+        :param mod_count: 单表队列数
         :return: 
         :last_editors: HuangJianYi
         """
-        mod_count = 10
+
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
             sub_table_count = config.get_value("stat_sub_table_count", 0)
@@ -35,7 +36,7 @@ class StatConsoleModel():
                 for i in range(sub_table_count):
                     self._start_process_stat_queue(str(i), mod_count)
         else:
-            self._start_process_redis_stat_queue(mod_count)
+            self._start_process_redis_stat_queue(10)
 
     def _start_process_stat_queue(self, sub_table, mod_count):
 
@@ -63,7 +64,10 @@ class StatConsoleModel():
         while True:
             try:
                 now_date = TimeHelper.get_now_format_time()
-                stat_queue_list = stat_queue_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
+                if mod_count == 1:
+                    stat_queue_list = stat_queue_model.get_list(f"process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
+                else:
+                    stat_queue_list = stat_queue_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
                 if len(stat_queue_list) > 0:
                     for stat_queue in stat_queue_list:
                         try:
@@ -159,8 +163,8 @@ class StatConsoleModel():
                 if not stat_queue_json:
                     time.sleep(1)
                     continue
-                stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
                 try:
+                    stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
                     sub_table = SevenHelper.get_sub_table(stat_queue_dict["act_id"], config.get_value("stat_sub_table_count", 0))
                     stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
                     stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
