@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2021-10-12 17:54:28
+@LastEditTime: 2021-12-06 15:30:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -34,9 +34,6 @@ class StatBaseModel(FrameBaseModel):
         :return:
         :last_editors: HuangJianYi
         """
-        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
-        stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
-
         stat_queue = StatQueue()
         stat_queue.app_id = app_id
         stat_queue.act_id = act_id
@@ -47,7 +44,15 @@ class StatBaseModel(FrameBaseModel):
         stat_queue.key_value = key_value
         stat_queue.create_date = SevenHelper.get_now_datetime()
         stat_queue.process_date = SevenHelper.get_now_datetime()
-        return stat_queue_model.add_entity(stat_queue)
+
+        stat_process_ways = config.get_value("stat_process_ways","mysql")
+        if stat_process_ways == "mysql":
+            sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
+            stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
+            stat_queue_model.add_entity(stat_queue)
+        else:
+            redis_init = SevenHelper.redis_init()
+            redis_init.rpush(f"stat_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
 
     def add_stat_list(self, app_id, act_id, module_id, user_id, open_id, key_list_dict):
         """
@@ -61,8 +66,6 @@ class StatBaseModel(FrameBaseModel):
         :return:
         :last_editors: HuangJianYi
         """
-        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
-        stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
         stat_queue_list = []
         for key,value in key_list_dict.items():
             stat_queue = StatQueue()
@@ -76,7 +79,16 @@ class StatBaseModel(FrameBaseModel):
             stat_queue.create_date = SevenHelper.get_now_datetime()
             stat_queue.process_date = SevenHelper.get_now_datetime()
             stat_queue_list.append(stat_queue)
-        return stat_queue_model.add_list(stat_queue_list)
+        
+        stat_process_ways = config.get_value("stat_process_ways","mysql")
+        if stat_process_ways == "mysql":
+            sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
+            stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
+            return stat_queue_model.add_list(stat_queue_list)
+        else:
+            redis_init = SevenHelper.redis_init()
+            for stat_queue in stat_queue_list:
+                redis_init.rpush(f"stat_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
 
     def get_stat_report_list(self,app_id,act_id,module_id,start_date,end_date,order_by="sort_index asc"):
         """
