@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2021-11-30 17:05:47
+@LastEditTime: 2021-12-06 18:31:12
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -137,7 +137,10 @@ class ThemeBaseModel():
 
         skin_info = SkinInfoModel(context=self.context).get_entity("theme_id=%s", params=theme_id)
         if not skin_info:
-            return self.response_json_error("error", "对不起，主题没有皮肤")
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "对不起，主题没有皮肤"
+            return invoke_result_data
         act_info_model.update_table("theme_id=%s", "id=%s", [theme_id, act_id])
         if is_module == True:
             ActModuleModel(context=self.context).update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])
