@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-12-16 19:22:39
+@LastEditTime: 2021-12-20 16:04:44
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -1272,3 +1272,35 @@ class TopBaseModel():
                         invoke_result_data.error_message = content[len("submsg="):]
                         return invoke_result_data
             return invoke_result_data
+
+    def get_project_code(self, user_nick, access_token,app_key, app_secret,is_log=False):
+        """
+        :description: 获取项目编码
+        :param user_nick：access_token
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return 字符串
+        :last_editors: HuangJianYi
+        """
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.VasSubscribeGetRequest()
+            req.article_code = config.get_value("article_code")
+            req.nick = user_nick
+            resp = req.getResponse(access_token)
+            if is_log:
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取项目编码】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取项目编码】")
+            if "article_user_subscribe" not in resp["vas_subscribe_get_response"]["article_user_subscribes"].keys():
+                return "expire"
+            return resp["vas_subscribe_get_response"]["article_user_subscribes"]["article_user_subscribe"][0]["item_code"]
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            return "expire"
