@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-12-16 16:27:51
+@LastEditTime: 2021-12-17 11:20:30
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -216,16 +216,14 @@ class UserBaseModel(FrameBaseModel):
                 user_account.open_id = open_id
                 user_account.user_nick = user_nick
                 user_account.avatar = avatar
-                user_account.is_auth = 0 if not user_nick else 1
                 user_account.user_state = 0
                 user_account.create_date = now_datetime
                 user_account.modify_date = now_datetime
                 user_account.id = user_account_model.add_entity(user_account)
             else:
                 user_account.user_nick = user_nick if user_nick and user_account.user_nick != user_nick else user_account.user_nick
-                user_account.is_auth = 0 if not user_account.user_nick else 1
                 user_account.avatar = avatar if avatar and user_account.avatar != avatar else user_account.avatar
-                user_account_model.update_entity(user_account, "user_nick,avatar,is_auth")
+                user_account_model.update_entity(user_account, "user_nick,avatar")
                 
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
